operator / method

  1. @override
Geographic operator /(
  1. Position divisor
)
override

Returns a position with coordinate values of this divided by values of divisor.

Examples:

// This usage of division operator returns a position of `[15.0, 15.0].xy`
[150.0, 300.0].xy / [10.0, 20.0].xy;

Implementation

@override
Geographic operator /(Position divisor) =>
    cartesianPositionDivision(this, divisor: divisor, to: Geographic.create);