MgrsGridSquare class
The 100km grid square (or the 100,000-meter square identifier) as a part of the grid zone in MGRS/NATO grid references.
Grid squares are identified by grid zone designators (GZD) like 31U, see
MgrsGridZone, and 100 km Grid Square IDs like DQ.
According to Wikipedia each UTM zone is divided into 100,000 meter squares, so that their corners have UTM-coordinates that are multiples of 100,000 meters.
See Mgrs for more information and representing MGRS grid references.
- Inheritance
-
- Object
- MgrsGridZone
- MgrsGridSquare
Constructors
- MgrsGridSquare(int lonZone, String band, String column, String row)
-
Creates a MGRS 100km grid square with
lonZone,band,columnandrow.factory
Properties
- band → String
-
The band represents 8° latitudinal band (C..X covering 80°S..84°N).
finalinherited
- column → String
-
The column (or "e100k") represents the first letter (E) of a 100km grid
square. Allowed letter characters are A..Z, omitting I and O.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- lonZone → int
-
The lonZone represents UTM 6° longitudinal zone (1..60 covering
180°W..180°E).
finalinherited
- row → String
-
The row (or "n100k") represents the second letter (N) of a 100km grid
square. Allowed letter characters are A..V, omitting I and O.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toText(
{bool militaryStyle = false, bool zeroPadZone = false}) → String -
The MGRS grid square string representation with components separated by
whitespace by default.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override