Temporal class abstract

A base class for temporal objects like instants and intervals.

Implementers

Constructors

Temporal()
Default const constructor to allow extending this abstract class.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isUtc → bool
True if this temporal object is set to UTC time.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isAfterTime(DateTime time) → bool
Returns true if this occurs fully after time.
isBeforeTime(DateTime time) → bool
Returns true if this occurs fully before time.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this temporal object.
override
toUtc() → Temporal
Returns this temporal object in the UTC time zone.

Operators

operator ==(Object other) → bool
The equality operator.
inherited