projected property

Projected projected
final

The projected position as UTM coordinates (x=easting, y=northing, z=elev) in the specified zone.

Easting is in metres from the false easting (-500km from the central meridian).

Northing is in metres from the equator (N) or from the false northing -10,000km (S).

2D positions are constructed as Projected(x: easting, y: northing) and 3D positions as Projected(x: easting, y: northing, z: elev).

The datum indicates the geodetic reference (ie. ellipsoid and other parameters) used when projecting geographic coordinates to projected coordinates.

See also easting and northing for direct access to the coordinates.

Implementation

final Projected projected;