toGeographic method
Converts UTM coordinates of this and represented by zone and projected based on the datum to a geographic position.
Implements Karney’s method, using Krüger series to order n⁶, giving results accurate to 5nm for distances up to 3900km from the central meridian.
If roundResults is true (default), then the results are rounded to the
reasonable precision, that is nm precision (1nm = 10^-14°).
This method returns a Geographic position object.
Examples:
final utm = Utm(31, 'N', 448251.795, 5411932.678);
final geographic = utm.toGeographic(); // 48°51′29.52″N, 002°17′40.20″E
See also toGeographicMeta and _toEllipsoidalMeta for methods returning
a geographic position with metadata.
Implementation
Geographic toGeographic({bool roundResults = true}) =>
_toEllipsoidalMeta(roundResults: roundResults).position.origin;