toGeographicMeta method
Converts UTM coordinates of this and represented by zone and projected based on the datum to a geographic position.
Implements Karney’s method, using Krüger series to order n⁶, giving results accurate to 5nm for distances up to 3900km from the central meridian.
If roundResults is true (default), then the results are rounded to the
reasonable precision, that is nm precision (1nm = 10^-14°).
This method returns a geographic position wrapped into an UtmMeta
object. The metadata includes UTM convergence and scale at the
calculated geographic position.
Examples:
final utm = Utm(31, 'N', 448251.795, 5411932.678);
final meta = utm.toGeographicMeta();
final geographic = meta.position; // 48°51′29.52″N, 002°17′40.20″E
final convergence = meta.convergence;
final scale = meta.scale;
See also toGeographic for a method returning a geographic position only.
Implementation
UtmMeta<Geographic> toGeographicMeta({bool roundResults = true}) =>
utmToGeographic(
zone: zone,
easting: easting,
northing: northing,
elev: projected.optZ,
m: projected.optM,
datum: datum,
roundResults: roundResults,
to: Geographic.create,
);