operator % method
Returns a position with coordinate values of this applied with modulo
operator % by values of divisor.
Examples:
// This usage of modulo operator returns a position of `[10.0, 170.0].xy`
[370.0, 170.0].xy % [360.0, 180.0].xy;
Implementation
@override
Geographic operator %(Position divisor) =>
cartesianPositionModulo(this, divisor: divisor, to: Geographic.create);