UtmMeta<T extends Object> class
Metadata (convergence and scale) as a result from UTM calculations related to position.
The position represents either a geographic position or projected UTM
coordinates as indicated by T, potentially with the geodetic datum
information.
The meridian convergence specifies the bearing of the grid north clockwise from the true north, in degrees.
The scale represents the UTM grid scale factor at position.
According to Wikipedia the scale factor at the central meridian is specified to be 0.9996 of true scale for most UTM systems in use.
See also Universal Transverse Mercator in Wikipedia for more information.
See also Utm for representing projected UTM coordinates.
- Annotations
-
- @immutable
Properties
- convergence → double
-
The meridian convergence specifies the bearing of the grid north
clockwise from the true north, in degrees.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- position → T
-
The position represents either a geographic position or projected UTM
coordinates as indicated by
T, potentially with the geodetic datum information.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
The scale represents the UTM grid scale factor at position.
final
- zone → UtmZone
-
The UTM zone of the position.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override